@@ -1,4 +1,4 @@
-# Copyright (c) 2016 - 2021, Adrian Dusa
+# Copyright (c) 2016 - 2022, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -23,8 +23,10 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-`XYplot` <- function(x, y, data, relation = "sufficiency", mguides = TRUE,
-                     jitter = FALSE, clabels = NULL, enhance = FALSE, model = FALSE, ...) {
+`XYplot` <- function(
+    x, y, data, relation = "sufficiency", mguides = TRUE,
+    jitter = FALSE, clabels = NULL, enhance = FALSE, model = FALSE, ...
+) {
     dots <- list(...)
     funargs <- unlist(lapply(match.call(), deparse)[-1])
     if (missing(x)) {
