@@ -1,4 +1,4 @@
-# Copyright (c) 2016 - 2021, Adrian Dusa
+# Copyright (c) 2016 - 2022, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -23,7 +23,9 @@
 # (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 # SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-`generate` <- function(expression = "", snames = "", noflevels = NULL) {
+`generate` <- function(
+    expression = "", snames = "", noflevels = NULL
+) {
     expression <- admisc::recreate(substitute(expression))
     snames <- admisc::recreate(substitute(snames))
     suf <- grepl("=>|->", expression)
